.. module:: enaml.widgets.main_window

=========================
enaml.widgets.main_window
=========================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    MainWindow


.. autoclass:: MainWindow
